GameServer.Friends.Friendship (game_server_sdk v1.0.15)

Copy Markdown View Source

Friendship struct from GameServer.

This is a stub module for SDK type definitions. The actual struct is provided by GameServer at runtime.

Fields

  • id - Friendship ID (integer)
  • requester_id - ID of the user who sent the request (integer)
  • target_id - ID of the user who received the request (integer)
  • requester - Preloaded requester User struct (optional)
  • target - Preloaded target User struct (optional)
  • status - One of: "pending", "accepted", "rejected", "blocked"
  • inserted_at - Creation timestamp
  • updated_at - Last update timestamp

Summary

Types

t()

@type t() :: %GameServer.Friends.Friendship{
  id: integer() | nil,
  inserted_at: DateTime.t() | nil,
  requester: GameServer.Accounts.User.t() | nil,
  requester_id: integer() | nil,
  status: String.t(),
  target: GameServer.Accounts.User.t() | nil,
  target_id: integer() | nil,
  updated_at: DateTime.t() | nil
}